==> snortsms-0.14.9.tbz: www/snortsms/dsp_menu.php <==
<table border="0" cellspacing="1" cellpadding="0">
<tr>
<td> 


	<div id="mainMenu">
		<ul id="menuList">
		
		
				<li class="menubar">
					<a href="#" class="starter" accesskey="1">Sensors</a>
					<ul id="menu1" class="menu">
					<li><a href="index.php?fuseaction=sensors.main">Administration Console</a></li>
					<li><a href="index.php?fuseaction=sensors.monitor">Monitoring Console</a></li>
          			</ul>
				</li>



        		<li class="menubar">
          			<a href="#" class="starter" accesskey="2">Libraries</a>
          			<ul id="menu2" class="menu">
					<li><a href="index.php?fuseaction=snortctrl.main">Snort Daemon Profiles</a></li>
					<li><a href="index.php?fuseaction=classifications.main">Classifications</a></li>
					<li><a href="index.php?fuseaction=outputs.main">Outputs</a></li>
					<li><a href="index.php?fuseaction=preprocessors.main">Preprocessors</a></li>
					<li><a href="index.php?fuseaction=references.main">References</a></li>
						<li>
							<a href="#" title="Rules">Rules >></a>
							<ul id="menu2_1" class="menu">
							<li><a href="index.php?fuseaction=rules.main">Rule Definitions</a></li>
							<li><a href="index.php?fuseaction=ruletypes.main">Rule Types</a></li>
							<li><a href="index.php?fuseaction=policies.main">Rule Profiles</a></li>
							</ul>
						</li>
					<li><a href="index.php?fuseaction=variables.main">Variables</a></li>
					<li><hr class="fore1"></li>
					<li><a href="index.php?fuseaction=barnctrl.main">Barnyard Daemon Profiles</a></li>
					<li><a href="index.php?fuseaction=barnyard.main">Barnyard Config</a></li>
					<li><hr class="fore1"></li>
					<li><a href="index.php?fuseaction=import.main">Import</a></li>
          			</ul>

        		</li>
		
		

        		<li class="menubar">
          			<a href="#" class="starter" accesskey="3">Alerts</a>
          			<ul id="menu3" class="menu">
					<li><a href="index.php?fuseaction=events.main">Snort Event Viewer</a></li>

          			</ul>

        		</li>


				
				
				<li class="menubar">
				<a href="#" class="starter" accesskey="4">Settings</a>
				<ul id="menu4" class="menu">
					<li><a href="index.php?fuseaction=conf.main">Global Settings</a>
					</li>
					
<!--
					<li><a href="#" title="Option 2">Option 4</a></li>
					<li>
						<a href="#" title="Sub Menu 1">Sub Menu 1 >></a>
						<ul id="menu3_1" class="menu">
							<li><a href="#" title="Option 2">Option 1</a></li>
							<li>
								<a href="#" title="Option 1">Sub Menu 1 >></a>
								<ul id="menu3_1_1" class="menu">
									<li><a href="#" title="Type 1">Type 1</a></li>
									<li><a href="#" title="Type 2">Type 2</a></li>
									<li><a href="#" title="Type 3">Type 3</a></li>
									<li><a href="#" title="Type 4">Type 4</a></li>
								</ul>
							</li>
							<li>
								<a href="#" title="Option 1">Sub Menu 2 >></a>
								<ul id="menu3_1_2" class="menu">
									<li><a href="#" title="Type 1">Type 1</a></li>
									<li><a href="#" title="Type 2">Type 2</a></li>
									<li><a href="#" title="Type 3">Type 3</a></li>
									<li><a href="#" title="Type 4">Type 4</a></li>
								</ul>
							</li>
						</ul>
					</li>
-->	
					
          		</ul>
        		</li>




				
				
				

      		</ul>
	</div>







</td>
</tr>
</table>

==> snortsms-1.0.0.tbz: www/snortsms/dsp_menu.php <==
<table border="0" cellspacing="1" cellpadding="0">
<tr>
<td> 


	<div id="mainMenu">
		<ul id="menuList">
		
		
				<li class="menubar">
					<a href="#" class="starter" accesskey="1">Sensors</a>
					<ul id="menu1" class="menu">
					<li><a href="index.php?fuseaction=sensors.main">Administration Console</a></li>
					<li><a href="index.php?fuseaction=sensors.monitor">Monitoring Console</a></li>
          			</ul>
				</li>



        		<li class="menubar">
          			<a href="#" class="starter" accesskey="2">Libraries</a>
          			<ul id="menu2" class="menu">
					<li><a href="index.php?fuseaction=snortctrl.main">Snort Daemon Profiles</a></li>
					<li><a href="index.php?fuseaction=configs.main">Config Directives</a></li>
					<li><a href="index.php?fuseaction=classifications.main">Classifications</a></li>
					<li><a href="index.php?fuseaction=outputs.main">Outputs</a></li>
					<li><a href="index.php?fuseaction=preprocessors.main">Preprocessors</a></li>
					<li><a href="index.php?fuseaction=references.main">References</a></li>
						<li>
							<a href="#" title="Rules">Rules >></a>
							<ul id="menu2_1" class="menu">
							<li><a href="index.php?fuseaction=rules.main">Rule Definitions</a></li>
							<li><a href="index.php?fuseaction=ruletypes.main">Rule Types</a></li>
							<li><a href="index.php?fuseaction=policies.main">Rule Profiles</a></li>
							</ul>
						</li>
					<li><a href="index.php?fuseaction=variables.main">Variables</a></li>
					<li><hr class="fore1"></li>
					<li><a href="index.php?fuseaction=barnctrl.main">Barnyard Daemon Profiles</a></li>
					<li><a href="index.php?fuseaction=barnyard.main">Barnyard Config</a></li>
					<li><hr class="fore1"></li>
					<li><a href="index.php?fuseaction=import.main">Import</a></li>
          			</ul>

        		</li>
		
		

        		<li class="menubar">
          			<a href="#" class="starter" accesskey="3">Alerts</a>
          			<ul id="menu3" class="menu">
					<li><a href="index.php?fuseaction=events.main">Snort Event Browser</a></li>
					<li><a href="index.php?fuseaction=events.searchform&sd=&st=">Snort Event Search</a></li>
          			</ul>

        		</li>


				
				
				<li class="menubar">
				<a href="#" class="starter" accesskey="4">Settings</a>
				<ul id="menu4" class="menu">
					<li><a href="index.php?fuseaction=conf.main">Global Settings</a></li>
					<li><a href="index.php?fuseaction=conf.test">Test Configuration</a></li>
<!--
					<li><a href="#" title="Option 2">Option 4</a></li>
					<li>
						<a href="#" title="Sub Menu 1">Sub Menu 1 >></a>
						<ul id="menu3_1" class="menu">
							<li><a href="#" title="Option 2">Option 1</a></li>
							<li>
								<a href="#" title="Option 1">Sub Menu 1 >></a>
								<ul id="menu3_1_1" class="menu">
									<li><a href="#" title="Type 1">Type 1</a></li>
									<li><a href="#" title="Type 2">Type 2</a></li>
									<li><a href="#" title="Type 3">Type 3</a></li>
									<li><a href="#" title="Type 4">Type 4</a></li>
								</ul>
							</li>
							<li>
								<a href="#" title="Option 1">Sub Menu 2 >></a>
								<ul id="menu3_1_2" class="menu">
									<li><a href="#" title="Type 1">Type 1</a></li>
									<li><a href="#" title="Type 2">Type 2</a></li>
									<li><a href="#" title="Type 3">Type 3</a></li>
									<li><a href="#" title="Type 4">Type 4</a></li>
								</ul>
							</li>
						</ul>
					</li>
-->	
					
          		</ul>
        		</li>




				
				
				

      		</ul>
	</div>







</td>
</tr>
</table>
